;; Generated package description from theme-buffet.el  -*- no-byte-compile: t -*-
(define-package "theme-buffet" "0.1.1" "Time based theme switcher" '((emacs "29.1")) :commit "4ba6fc865c103a5930e000c0c42559dd0aa1209d" :authors '(("Bruno Boal" . "egomet@bboal.com") ("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Theme-Buffet Development" . "~bboal/general-issues@lists.sr.ht") :url "https://git.sr.ht/~bboal/theme-buffet")
